@@ -18,10 +18,13 @@ new_defaults = function(value = list()) {
       if (length(dots <- dots[[1]]) == 0) return()
     dots
   }
+  set2 = function(values) {
+    old = get(names(values), drop = FALSE)
+    if (length(values)) defaults <<- merge(values)
+    invisible(old)
+  }
   set = function(...) {
-    dots = resolve(...)
-    if (length(dots)) defaults <<- merge(dots)
-    invisible(NULL)
+    set2(resolve(...))
   }
   delete = function(keys) {
     for (k in keys) defaults[[k]] <<- NULL
@@ -31,8 +34,7 @@ new_defaults = function(value = list()) {
   append = function(...) {
     dots = resolve(...)
     for (i in names(dots)) dots[[i]] <- c(defaults[[i]], dots[[i]])
-    if (length(dots)) defaults <<- merge(dots)
-    invisible(NULL)
+    set2(dots)
   }
 
   list(
@@ -67,10 +69,13 @@ new_defaults = function(value = list()) {
 #' @export
 #' @examples opts_chunk$get('prompt'); opts_chunk$get('fig.keep')
 opts_chunk = new_defaults(list(
-
   eval = TRUE, echo = TRUE, results = 'markup', tidy = FALSE, tidy.opts = NULL,
   collapse = FALSE, prompt = FALSE, comment = '##', highlight = TRUE,
-  strip.white = TRUE, size = 'normalsize', background = '#F7F7F7',
+  size = 'normalsize', background = '#F7F7F7',
+
+  # value wrapped in I() means a change in default option later
+  # (e.g in fix_options, conditionally to other argument)
+  strip.white = I(TRUE),
 
   cache = FALSE, cache.path = 'cache/', cache.vars = NULL, cache.lazy = TRUE,
   dependson = NULL, autodep = FALSE, cache.rebuild = FALSE,
@@ -119,6 +124,7 @@ opts_chunk_attr = local({
   opts$fig.asp = 'numeric'
   opts$fig.alt = 'character'
   opts$fig.dim = 'list'
+  opts$lang = 'list'
   opts$R.options = 'list'
   opts$cache.comments = 'logical'
   opts$animation.hook = list('ffmpeg', 'gifski')
@@ -167,7 +173,7 @@ set_alias = function(...) {
 #' }
 #' @include hooks-html.R
 opts_knit = new_defaults(list(
-  progress = TRUE, verbose = FALSE, eval.after = c('fig.cap', 'fig.alt'),
+  progress = TRUE, verbose = FALSE, eval.after = c('fig.cap', 'fig.scap', 'fig.alt'),
   base.dir = NULL, base.url = NULL, root.dir = NULL, child.path = '',
   upload.fun = identity, global.device = FALSE, global.par = FALSE,
   concordance = FALSE, documentation = 1L, self.contained = TRUE,
