@@ -27,7 +27,7 @@ line_prompt = function(x, prompt = getOption('prompt'), continue = getOption('co
 # add a prefix to output
 comment_out = function(x, prefix = '##', which = TRUE, newline = TRUE) {
   x = gsub('[\n]{2,}$', '\n', x)
-  if (newline) x = gsub('([^\n])$', '\\1\n', x)  # add \n if not exists
+  if (newline) x = gsub('([^\n]|^)$', '\\1\n', x)  # add \n if not exists
   if (is.null(prefix) || !nzchar(prefix) || is.na(prefix)) return(x)
   prefix = paste(prefix, '')
   x = gsub(' +([\n]*)$', '\\1', x)
@@ -148,35 +148,31 @@ output_asis = function(x, options) {
   is_blank(x) || options$results == 'asis'
 }
 
-# path relative to dir of the input file
-input_dir = function(ignore_root = FALSE) {
+# the working directory: use root.dir if specified, otherwise the dir of the
+# input file unless knitr.use.cwd = TRUE
+input_dir = function() {
   root = opts_knit$get('root.dir')
-  # LyX is a special case: the input file is in tempdir, and we should use
-  # root.dir as the real input dir (#809)
-  if (is_lyx()) return(root)
-  if (ignore_root) {
-    .knitEnv$input.dir %n% '.'
-  } else {
-    root %n% (if (!getOption('knitr.use.cwd', FALSE)) .knitEnv$input.dir) %n% '.'
-  }
+  root %n% (if (!getOption('knitr.use.cwd', FALSE)) .knitEnv$input.dir) %n% '.'
 }
 
-is_lyx = function() {
-  args = commandArgs(TRUE)
-  if (length(args) < 4) return(FALSE)
-  grepl('[.]Rnw$', args[1]) && !is.na(Sys.getenv('LyXDir', NA))
-}
+# eval expr under the input dir
+in_input_dir = function(expr) in_dir(input_dir(), expr)
 
-# detect if running on CRAN (assuming that CRAN does not set CI or NOT_CRAN=true)
+# detect if running on CRAN (assuming that CRAN does not set CI or
+# NOT_CRAN=true); or set R_CRANDALF=true (is cran) or false (not cran)
 is_cran = function() {
-  tolower(Sys.getenv('R_CRANDALF')) == 'true' ||
+  x = Sys.getenv('R_CRANDALF', NA)
+  if (!is.na(x)) tolower(x) == 'true' else {
     !any(tolower(Sys.getenv(c('CI', 'NOT_CRAN'))) == 'true')
+  }
 }
 
 is_cran_check = function() {
   is_cran() && is_R_CMD_check()
 }
 
+is_bioc = function() Sys.getenv('BBS_HOME') != ''
+
 # round a number to getOption('digits') decimal places by default, and format()
 # it using significant digits if the option knitr.digits.signif = TRUE
 round_digits = function(x) {
@@ -375,7 +371,8 @@ is_latex_output = function() {
 #'   provided, \code{is_html_output()} uses \code{pandoc_to()}, and
 #'   \code{pandoc_to()} returns the output format name.
 #' @param excludes A character vector of output formats that should not be
-#'   considered as HTML format.
+#'   considered as HTML format. Options are: markdown, epub, html, html4, html5,
+#'   revealjs, s5, slideous, slidy, and gfm.
 #' @rdname output_type
 #' @export
 is_html_output = function(fmt = pandoc_to(), excludes = NULL) {
@@ -419,7 +416,7 @@ latex_percent_size = function(x, which = c('width', 'height')) {
 # eval options as symbol/language objects
 eval_lang = function(x, envir = knit_global()) {
   if (!is.symbol(x) && !is.language(x)) return(x)
-  eval(x, envir = envir)
+  in_input_dir(eval(x, envir = envir))
 }
 
 # check latex packages; if not exist, copy them over to ./
@@ -810,9 +807,12 @@ knit_handlers = function(fun, options) {
   if (length(formals(fun)) < 2)
     stop("the chunk option 'render' must be a function of the form ",
          "function(x, options) or function(x, ...)")
-  merge_list(default_handlers, list(value = function(x, visible) {
-    if (visible) fun(x, options = options)
-  }))
+  merge_list(default_handlers, list(
+    value = function(x, visible) {
+      if (visible) fun(x, options = options)
+    },
+    calling_handlers = options$calling.handlers
+  ))
 }
 
 # is the inst dir under . or ..? differs in R CMD build/INSTALL and devtools/roxygen2
@@ -1029,6 +1029,9 @@ digest3 = function(x) {
 # collapse by \n
 one_string = function(x, ...) paste(x, ..., collapse = '\n')
 
+# double quote a vector and combine by "; "
+quote_vec = function(x, sep = '; ') paste0(sprintf('"%s"', x), collapse = sep)
+
 # c(1, 1, 1, 2, 3, 3) -> c(1a, 1b, 1c, 2a, 3a, 3b)
 make_unique = function(x) {
   if (length(x) == 0) return(x)
